Commit in lcsim-contrib/src/main/java/org/lcsim/contrib/onoprien on MAIN
performance/Definition.java+3-31.2 -> 1.3
tooldrivers/CalorimeterDriver.java+3-21.1 -> 1.2
+6-5
2 modified files
Fix javadoc warnings

lcsim-contrib/src/main/java/org/lcsim/contrib/onoprien/performance
Definition.java 1.2 -> 1.3
diff -u -r1.2 -r1.3
--- Definition.java	10 Jul 2009 19:25:05 -0000	1.2
+++ Definition.java	10 Jul 2009 22:34:47 -0000	1.3
@@ -31,7 +31,7 @@
  * {@link #isFound isFound}, and {@link #isFake isFake} methods.
  *
  * @author D. Onoprienko
- * @version $Id: Definition.java,v 1.2 2009/07/10 19:25:05 onoprien Exp $
+ * @version $Id: Definition.java,v 1.3 2009/07/10 22:34:47 onoprien Exp $
  */
 public class Definition implements IDefinition {
 
@@ -384,7 +384,7 @@
   /**
    * Sets collection names that should be looked into when deciding whether an object of
    * a particular type has been successfully reconstructed. If names are not set, default
-   * names supplied through {@link MCTruthDriver} will be used.
+   * names set for {@link MCTruth} through {@link JobManager} will be used.
    */
   public void setCollectionName(RecType type, String... collectionName) {
     _colNames.put(type, collectionName);
@@ -693,7 +693,7 @@
 
   /**
    * Saves a reference to the event record to be used by this definition.
-   * If a driver calls this method, it has to call {@link #clearEvent()} once the event
+   * If a driver calls this method, it has to call {@link #endEvent()} once the event
    * processing is finished.
    */
   public void startEvent(EventHeader event) {

lcsim-contrib/src/main/java/org/lcsim/contrib/onoprien/tooldrivers
CalorimeterDriver.java 1.1 -> 1.2
diff -u -r1.1 -r1.2
--- CalorimeterDriver.java	8 Jul 2009 15:59:34 -0000	1.1
+++ CalorimeterDriver.java	10 Jul 2009 22:34:47 -0000	1.2
@@ -12,15 +12,16 @@
 
 import org.lcsim.contrib.onoprien.geom.calorimeter.CalGeometry;
 import org.lcsim.contrib.onoprien.data.CalHitFilter;
+import org.lcsim.contrib.onoprien.data.CalHitMap;
 
 /**
  * Driver that initializes calorimeter geometry and processes hits.
  * <p>
  * Runs Digisim to digitize hits, puts them into a {@link CruxHitMap}, adds the map
  * to the event record.
  *
  * @author D. Onoprienko
- * @version $Id: CalorimeterDriver.java,v 1.1 2009/07/08 15:59:34 onoprien Exp $
+ * @version $Id: CalorimeterDriver.java,v 1.2 2009/07/10 22:34:47 onoprien Exp $
  */
 public class CalorimeterDriver extends Driver implements JobEventListener {
 
@@ -12,15 +12,16 @@
  * Driver that initializes calorimeter geometry and processes hits.
  * <p>
- * Runs Digisim to digitize hits, puts them into a {@link CruxHitMap}, adds the map
+ * Runs Digisim to digitize hits, puts them into a {@link CalHitMap}, adds the map
  * to the event record.
  *
CVSspam 0.2.8